#!/usr/bin/python
# encoding=utf-8

"""
@Author  :  Lijiawei
@Date    :  2022/11/26 3:19 下午
@Desc    :  __init__.py line.
"""
__version__ = '1.0.4'
__description__ = 'Stability testing tool based on fastbot transformation.'
