#!/usr/bin/python
# encoding=utf-8

"""
@Author  :  Lijiawei
@Date    :  2022/11/27 3:37 下午
@Desc    :  main line.
"""
import fire as fire

from macaque.core import prepare

if __name__ == '__main__':
    fire.Fire(prepare)
